// mpfType.h
// architecture independent types

// Author:  Marty Kraimer Date:  03MAR1998 
// adapted from epicsTypes.h

/*************************************************************************
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory, and the Regents of the University of California, as
* Operator of Los Alamos National Laboratory. MPF is distributed
* subject to a Software License Agreement found in file LICENSE that
* is included with this distribution.
*************************************************************************/
#ifndef mpfTypeH
#define mpfTypeH

// Architecture Independent Data Types
// so far this is sufficient for all archs we have ported to

typedef char            char8;
typedef short           int16;
typedef unsigned short  uint16;
typedef int             int32;
typedef unsigned 	uint32;
typedef float           float32;
typedef double          float64;

	
// Corresponding Type Codes
//
enum mpfType {
    char8T,
    int16T, uint16T,
    int32T, uint32T,
    float32T, float64T
};

#define firstMpfType 	char8T
#define lastMpfType 	float64T 
#define validMpfType(x)	((x>=firstMpfType) && (x<=lastMpfType))
#define invalidMpfType(x) ((x<firstMpfType) || (x>lastMpfType))


// The enumeration "mpfType" is an index to this array of type name strings.

extern const char *mpfTypeName[lastMpfType+1];
extern const unsigned mpfTypeSize[lastMpfType+1];

#ifdef mpfTypeGLOBAL
const char *mpfTypeName[lastMpfType+1] = {
    "char8",
    "int16", "uint16",
    "int32", "uint32",
    "float32", "float64",
};

extern const unsigned mpfTypeSize[lastMpfType+1] = {
    sizeof(char8),
    sizeof(int16),
    sizeof(uint16),
    sizeof(int32),
    sizeof(uint32),
    sizeof(float32),
    sizeof(float64),
};
#endif // mpfTypeGLOBAL 

#endif //mpfTypeH

