// DevMpfInt32Test.cc
/*************************************************************************
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory, and the Regents of the University of California, as
* Operator of Los Alamos National Laboratory. MPF is distributed
* subject to a Software License Agreement found in file LICENSE that
* is included with this distribution.
*************************************************************************/

#include <stdlib.h>
#include <stddef.h>
#include <string.h>
#include <stdio.h>
 
#include <dbAccess.h>
#include <dbDefs.h>
#include <link.h>
#include <epicsPrint.h>
#include <dbCommon.h>
#include <aiRecord.h>
#include <recSup.h>
#include <alarm.h>
#include <recGbl.h>
 
#include "Message.h"
#include "Int32Message.h"
#include "DevMpf.h"


// EPICS device support for MPF is class derived from DevMpf

class DevMpfInt32Test : public DevMpf
{
public:
    DevMpfInt32Test(dbCommon*,DBLINK*);

    long startIO(dbCommon* pr);
    long completeIO(dbCommon* pr,Message* m);
    static long dev_init(void*);
    int counter; // the value to send to server
private:
    // disallow
    DevMpfInt32Test();
    DevMpfInt32Test(const DevMpfInt32Test &);
    DevMpfInt32Test& operator=(const DevMpfInt32Test&);
};

// use this macro to create the EPICS DSET.  first parm is the DSET name
// (the one that will be in the devSup.ascii), the second is the record
// initialization function for the DSET.  Here it is set to the static
// member function of the class int32Test defined above.

MAKE_LINCONV_DSET(devMpfInt32Test,DevMpfInt32Test::dev_init)

// dev_init is called at record initialization time.
//The void* argument is the record pointer.
// dev_init also tests for connection. If connected it send a message

long DevMpfInt32Test::dev_init(void* v)
{
    aiRecord* pai = (aiRecord*)v;

    // create the instance of our class here, passing
    // it the record pointer and link pointer
    DevMpfInt32Test* pDevMpfInt32Test =
	new DevMpfInt32Test((dbCommon*)pai,&(pai->inp));
    pDevMpfInt32Test->bind();
    // test connectWait and sendWait
    if(!pDevMpfInt32Test->connectWait(.9)) {
        printf("%s connectWait failed\n",pai->name);
    } else {
        Int32Message *message = new Int32Message;
        message->value = pDevMpfInt32Test->counter;
        int sendStatus = pDevMpfInt32Test->sendWait(message,replyTypeReceiveReply);
        if(sendStatus) printf("%s sendWait failed\n",pai->name);
    }
    // status is stored in the base class
    return(pDevMpfInt32Test->getStatus());
}

// Constructor for the this device class

DevMpfInt32Test::DevMpfInt32Test(dbCommon* pr,DBLINK* l) : DevMpf(pr,l,false)
{
    aiRecord *pai = (aiRecord *)pr;
    // can get user parm area from here with getUserParm() and do stuff
    counter = (int)pai->egul;
}

// Start the asynchronous IO here.  Get a message buffer, fill in the 
// value field, and send it to the remote.

long DevMpfInt32Test::startIO(dbCommon* pr)
{
    aiRecord *pai = (aiRecord *)pr;
    Int32Message *message = new Int32Message;
    if(++counter >  (int)pai->eguf) counter = (int)pai->egul;
    message->value = counter;
    return(sendReply(message));
}

// Complete the asynchronous IO operation.
long DevMpfInt32Test::completeIO(dbCommon* pr,Message* pmessage)
{
    aiRecord* ai_rec = (aiRecord*)pr;
    if((pmessage->getType()) != messageTypeInt32) {
	epicsPrintf("DevMpfInt32Test::completeIO illegal message. %s\n",
	    ai_rec->name);
	recGblSetSevr(pr,READ_ALARM,INVALID_ALARM);
	return(MPF_NoConvert);
    }
    Int32Message *pint32Message = (Int32Message *)pmessage;
    ai_rec->val = (double)pint32Message->value;
    ai_rec->udf = 0;
    delete pint32Message;
    return(MPF_NoConvert);
}
