// mpfTestRegister.cpp
/*************************************************************************
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory, and the Regents of the University of California, as
* Operator of Los Alamos National Laboratory. MPF is distributed
* subject to a Software License Agreement found in file LICENSE that
* is included with this distribution.
*************************************************************************/

#include <stdlib.h>
#include <stddef.h>
#include <string.h>
#include <stdio.h>

#include <iocsh.h>
#include <epicsExport.h>

#include "Message.h"
#include "test.h"

extern "C" {

//clientChar8Array
static const iocshArg clientChar8ArrayArg0 =
    { "server",iocshArgString};
static const iocshArg clientChar8ArrayArg1 =
    { "slot",iocshArgInt};
static const iocshArg clientChar8ArrayArg2 =
    { "arraySize",iocshArgInt};
static const iocshArg clientChar8ArrayArg3 =
    { "delay",iocshArgDouble};
static const iocshArg * const clientChar8ArrayArgs[4]
    = {&clientChar8ArrayArg0,&clientChar8ArrayArg1,
       &clientChar8ArrayArg2,&clientChar8ArrayArg3};
static const iocshFuncDef clientChar8ArrayFuncDef
    = {"initClientChar8Array",4,clientChar8ArrayArgs};
static void clientChar8ArrayCallFunc(const iocshArgBuf *args)
{
    initClientChar8Array(args[0].sval,args[1].ival,
        args[2].ival,args[3].dval);
}

//clientInt32
static const iocshArg clientInt32Arg0 =
    { "server",iocshArgString};
static const iocshArg clientInt32Arg1 =
    { "slot",iocshArgInt};
static const iocshArg clientInt32Arg2 =
    { "ntoBuffer",iocshArgInt};
static const iocshArg clientInt32Arg3 =
    { "delay",iocshArgDouble};
static const iocshArg * const clientInt32Args[4]
    = {&clientInt32Arg0,&clientInt32Arg1,
       &clientInt32Arg2,&clientInt32Arg3};
static const iocshFuncDef clientInt32FuncDef
    = {"initClientInt32",4,clientInt32Args};
static void clientInt32CallFunc(const iocshArgBuf *args)
{
    initClientInt32(args[0].sval,args[1].ival,
        args[2].ival,args[3].dval);
}

//serverChar8Array
static const iocshArg serverChar8ArrayArg0 =
    { "server",iocshArgString};
static const iocshArg serverChar8ArrayArg1 =
    { "queueSize",iocshArgInt};
static const iocshArg * const serverChar8ArrayArgs[2]
    = {&serverChar8ArrayArg0,&serverChar8ArrayArg1};
static const iocshFuncDef serverChar8ArrayFuncDef
    = {"initServerChar8Array",2,serverChar8ArrayArgs};
static void serverChar8ArrayCallFunc(const iocshArgBuf *args)
{
    initServerChar8Array(args[0].sval,args[1].ival);
}

//serverInt32
static const iocshArg serverInt32Arg0 =
    { "server",iocshArgString};
static const iocshArg serverInt32Arg1 =
    { "queueSize",iocshArgInt};
static const iocshArg * const serverInt32Args[2]
    = {&serverInt32Arg0,&serverInt32Arg1};
static const iocshFuncDef serverInt32FuncDef
    = {"initServerInt32",2,serverInt32Args};
static void serverInt32CallFunc(const iocshArgBuf *args)
{
    initServerInt32(args[0].sval,args[1].ival);
}

//messageTest
static const iocshArg messageTestArg0 =
    { "ntimes",iocshArgInt};
static const iocshArg * const messageTestArgs[1]
    = {&messageTestArg0};
static const iocshFuncDef messageTestFuncDef
    = {"initMessageTest",1,messageTestArgs};
static void messageTestCallFunc(const iocshArgBuf *args)
{
    initMessageTest(args[0].ival);
}


//clientChar8ArrayDebug
static const iocshArg clientChar8ArrayDebugArg0 = { "value",iocshArgInt};
static const iocshArg * const clientChar8ArrayDebugArgs[1] = {&clientChar8ArrayDebugArg0};
static const iocshFuncDef clientChar8ArrayDebugFuncDef = {"setClientChar8ArrayDebug",1,clientChar8ArrayDebugArgs};
static void clientChar8ArrayDebugCallFunc(const iocshArgBuf *args)
{
    clientChar8ArrayDebug = args[0].ival;
}

//clientInt32Debug
static const iocshArg clientInt32DebugArg0 = { "value",iocshArgInt};
static const iocshArg * const clientInt32DebugArgs[1] = {&clientInt32DebugArg0};
static const iocshFuncDef clientInt32DebugFuncDef = {"setClientInt32Debug",1,clientInt32DebugArgs};
static void clientInt32DebugCallFunc(const iocshArgBuf *args)
{
    clientInt32Debug = args[0].ival;
}

//serverChar8ArrayDebug
static const iocshArg serverChar8ArrayDebugArg0 = { "value",iocshArgInt};
static const iocshArg * const serverChar8ArrayDebugArgs[1] = {&serverChar8ArrayDebugArg0};
static const iocshFuncDef serverChar8ArrayDebugFuncDef = {"setServerChar8ArrayDebug",1,serverChar8ArrayDebugArgs};
static void serverChar8ArrayDebugCallFunc(const iocshArgBuf *args)
{
    serverChar8ArrayDebug = args[0].ival;
}

//serverInt32Debug
static const iocshArg serverInt32DebugArg0 = { "value",iocshArgInt};
static const iocshArg * const serverInt32DebugArgs[1] = {&serverInt32DebugArg0};
static const iocshFuncDef serverInt32DebugFuncDef = {"setServerInt32Debug",1,serverInt32DebugArgs};
static void serverInt32DebugCallFunc(const iocshArgBuf *args)
{
    serverInt32Debug = args[0].ival;
}


static void mpfTestRegister(void)
{
    iocshRegister(&clientChar8ArrayFuncDef,clientChar8ArrayCallFunc);
    iocshRegister(&clientInt32FuncDef,clientInt32CallFunc);
    iocshRegister(&serverChar8ArrayFuncDef,serverChar8ArrayCallFunc);
    iocshRegister(&serverInt32FuncDef,serverInt32CallFunc);
    iocshRegister(&messageTestFuncDef,messageTestCallFunc);
    iocshRegister(&clientChar8ArrayDebugFuncDef,clientChar8ArrayDebugCallFunc);
    iocshRegister(&clientInt32DebugFuncDef,clientInt32DebugCallFunc);
    iocshRegister(&serverChar8ArrayDebugFuncDef,serverChar8ArrayDebugCallFunc);
    iocshRegister(&serverInt32DebugFuncDef,serverInt32DebugCallFunc);
}

static void mpfTestRegistrar(void)
{
    mpfTestRegister();
}
epicsExportRegistrar(mpfTestRegistrar);

} // extern "C"

